@@ -1,10 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-    # mailshake.message
-
-    A container for email information.
-
-"""
 from email import charset as Charset, encoders as Encoders
 from email.generator import Generator
 from email.mime.text import MIMEText
@@ -75,11 +69,15 @@ class EmailMessage(object):
         msg = self._create_message()
         msg['Subject'] = self.subject
         msg['From'] = self.extra_headers.get('From', self.from_email)
-        msg['To'] = ', '.join(self.to)
+
+        if not self.get_recipients():
+            pass
+
+        if self.to:
+            msg['To'] = ', '.join(self.to)
+
         if self.cc:
             msg['Cc'] = ', '.join(self.cc)
-        if self.bcc:
-            msg['Bcc'] = ', '.join(self.bcc)
 
         # Email header names are case-insensitive (RFC 2045), so we have to
         # accommodate that when doing comparisons.
